trunk

Function trunk 

pub async fn trunk(args: ArgsOs) -> Result<()>
Prints the name of the local trunk branch, if any is identified.

Errors

Returns an error if args is nonempty, or no local trunk can be identified.